@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2015 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -47,7 +47,6 @@ my %warn_if_match_payload = (
     type       => 'hash',
     index_type => 'string',
     level      => 'hidden',
-    experience => 'advanced',
     cargo      => {
         type              => 'node',
         config_class_name => 'Itself::CommonElement::WarnIfMatch',
@@ -59,7 +58,6 @@ my %assert_payload = (
     type       => 'hash',
     index_type => 'string',
     level      => 'hidden',
-    experience => 'advanced',
     cargo      => {
         type              => 'node',
         config_class_name => 'Itself::CommonElement::Assert',
@@ -75,7 +73,7 @@ my %assert_payload = (
                 type       => 'leaf',
                 value_type => 'string',
                 description =>
-'Warning message to show user. Leave blank or undef to use generated message',
+'Warning message to show user. "$_" will contain the bad value. Example "value $_ is bad". Leave blank or undef to use generated message',
             },
             fix => {
                 type       => 'leaf',
@@ -172,10 +170,9 @@ my %assert_payload = (
 
             'min' => {
                 type        => 'leaf',
-                value_type  => 'integer',
+                value_type  => 'number',
                 level       => 'hidden',
                 description => 'minimum value',
-                experience  => 'advanced',
                 warp        => {
                     follow => {
                         'type'  => '?type',
@@ -194,10 +191,9 @@ my %assert_payload = (
 
             'max' => {
                 type        => 'leaf',
-                value_type  => 'integer',
+                value_type  => 'number',
                 level       => 'hidden',
                 description => 'maximum value',
-                experience  => 'advanced',
                 warp        => {
                     follow => {
                         'type'  => '?type',
@@ -218,7 +214,6 @@ my %assert_payload = (
                 type        => 'leaf',
                 value_type  => 'integer',
                 level       => 'hidden',
-                experience  => 'advanced',
                 description => 'minimum number of keys',
                 warp        => {
                     follow  => { 'type' => '?type', },
@@ -233,7 +228,6 @@ my %assert_payload = (
                 type        => 'leaf',
                 value_type  => 'integer',
                 level       => 'hidden',
-                experience  => 'advanced',
                 description => 'maximum number of keys',
                 warp        => {
                     follow  => { 'type' => '?type', },
@@ -272,7 +266,6 @@ my %assert_payload = (
                 type       => 'leaf',
                 value_type => 'enum',
                 level      => 'hidden',
-                experience => 'advanced',
                 description => 'Convert value or index to uppercase (uc) or lowercase (lc).',
                 warp => {
                     follow  => { 't' => '?type' },
@@ -289,7 +282,6 @@ my %assert_payload = (
                 type       => 'leaf',
                 value_type => 'uniline',
                 level      => 'hidden',
-                experience => 'advanced',
                 description =>
                     'Perl regular expression to assert the validity of the value. To check the '
                     . q!whole value, use C<^> and C<$>. For instance C<^foo|bar$> will allow !
@@ -307,6 +299,11 @@ my %assert_payload = (
                   . 'also be run on undefined value, which may not be what you want.',
             },
 
+            'warn_if' => {
+                %assert_payload,
+                description => 'Warn user if the code snippet returns true',
+            },
+
             'warn_unless' => {
                 %assert_payload,
                 description =>
@@ -329,7 +326,6 @@ my %assert_payload = (
                 type       => 'leaf',
                 value_type => 'string',
                 level      => 'hidden',
-                experience => 'advanced',
                 description =>
 'Unconditionally issue a warning with this string when this parameter is used. This should be used mostly with "accept"',
                 warp => {
@@ -342,7 +338,6 @@ my %assert_payload = (
                 type       => 'leaf',
                 value_type => 'string',
                 level      => 'hidden',
-                experience => 'advanced',
                 description =>
 "Feed this grammar to Parse::RecDescent to perform validation",
                 @warp_in_uniline_or_string,
