@@ -1,12 +1,12 @@
-# 
+#
 # This file is part of Config-Model-Itself
-# 
-# This software is Copyright (c) 2010 by Dominique Dumont.
-# 
+#
+# This software is Copyright (c) 2015 by Dominique Dumont.
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU Lesser General Public License, Version 2.1, February 1999
-# 
+#
 #    Copyright (c) 2007-2008 Dominique Dumont.
 #
 #    This file is part of Config-Model-Itself.
@@ -59,6 +59,7 @@
            value_type => 'enum', 
            choice => [qw/master advanced beginner/] ,
            upstream_default => 'beginner',
+           status => 'deprecated',
            description => 'Used to categorize configuration elements in several "required skills". Use this feature if you need to hide a parameter to novice users',
           },
 
@@ -89,7 +90,6 @@
       'warp' 
       => { type => 'warped_node' , # ?
            level => 'hidden',
-           experience => 'advanced',
            follow => { elt_type => '- type' } ,
            rules  => [
                       '$elt_type ne "node"' =>
